0.9.9 API documentation: GLM_GTX_color_space_YCoCg

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_color_space_YCoCg
Experimental extensions

Include <glm/gtx/color_space_YCoCg.hpp> to use the features of this extension. More...

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | rgb2YCoCg (vec< 3, T, Q > const &rgbColor)
| Convert a color from RGB color space to YCoCg color space. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | rgb2YCoCgR (vec< 3, T, Q > const &rgbColor)
| Convert a color from RGB color space to YCoCgR color space. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | YCoCg2rgb (vec< 3, T, Q > const &YCoCgColor)
| Convert a color from YCoCg color space to RGB color space. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | YCoCgR2rgb (vec< 3, T, Q > const &YCoCgColor)
| Convert a color from YCoCgR color space to RGB color space. More...

## Detailed Description

Include <glm/gtx/color_space_YCoCg.hpp> to use the features of this extension.

RGB to YCoCg conversions and operations

## Function Documentation

GLM_FUNC_DECL vec<3, T, Q> glm::rgb2YCoCg | ( | vec< 3, T, Q > const & | rgbColor | ) |

Convert a color from RGB color space to YCoCg color space.

See also
  GLM_GTX_color_space_YCoCg

GLM_FUNC_DECL vec<3, T, Q> glm::rgb2YCoCgR | ( | vec< 3, T, Q > const & | rgbColor | ) |

Convert a color from RGB color space to YCoCgR color space.

See also
  "YCoCg-R: A Color Space with RGB Reversibility and Low Dynamic Range"
  GLM_GTX_color_space_YCoCg

GLM_FUNC_DECL vec<3, T, Q> glm::YCoCg2rgb | ( | vec< 3, T, Q > const & | YCoCgColor | ) |

Convert a color from YCoCg color space to RGB color space.

See also
  GLM_GTX_color_space_YCoCg

GLM_FUNC_DECL vec<3, T, Q> glm::YCoCgR2rgb | ( | vec< 3, T, Q > const & | YCoCgColor | ) |

Convert a color from YCoCgR color space to RGB color space.

See also
  "YCoCg-R: A Color Space with RGB Reversibility and Low Dynamic Range"
  GLM_GTX_color_space_YCoCg